function handles = decorate(a_plot, plot_handles)

% decorate - No additional decorations for stacked plots.
%
% Usage:
% a_histogram_db = decorate(a_plot)
%
% Description:
%
%   Parameters:
%	a_plot: A plot_abstract object, or a subclass object.
%		
%   Returns:
%	handles: Handles of graphical objects drawn.
%
% See also: plot_abstract, plot_abstract/plot
%
% $Id$
%
% Author: Cengiz Gunay <cgunay@emory.edu>, 2004/10/04

% Copyright (c) 2007 Cengiz Gunay <cengique@users.sf.net>.
% This work is licensed under the Academic Free License ("AFL")
% v. 3.0. To view a copy of this license, please look at the COPYING
% file distributed with this software or visit
% http://opensource.org/licenses/afl-3.0.php.

plot_handles = defaultValue('plot_handles', []);

handles = struct([]);

% Put a title?
%handles.title = title(get(a_plot, 'title'));
